<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>Sobre o Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="49"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="63"/>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="77"/>
        <source>Translators</source>
        <translation>Tradutores</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="91"/>
        <source>Thanks To</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="105"/>
        <source>License Agreement</source>
        <translation>Contrato de licenciamento</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation>Qt-based Multimedia Player (Qmmp)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="67"/>
        <source>Version: %1</source>
        <translation>Versão: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Using Qt %1 (compiled with Qt %2)</source>
        <translation>Utiliza Qt %1 (compilado com Qt %2)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="71"/>
        <source>(c) %1-%2 Qmmp Development Team</source>
        <translation>(c) %1-%2 Equipa de desenvolvimento do Qmmp</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Input plugins:</source>
        <translation>Suplementos de entrada:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="85"/>
        <source>Output plugins:</source>
        <translation>Suplementos de saída:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>Visual plugins:</source>
        <translation>Suplementos visuais:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="103"/>
        <source>Effect plugins:</source>
        <translation>Suplementos de efeitos:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="112"/>
        <source>General plugins:</source>
        <translation>Suplementos genéricos:</translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../forms/addurldialog.ui" line="14"/>
        <source>Enter URL to add</source>
        <translation>Introduza o URL a adicionar</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="46"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="53"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../addurldialog.cpp" line="124"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>ColumnEditor</name>
    <message>
        <location filename="../forms/columneditor.ui" line="14"/>
        <source>Edit Column</source>
        <translation>Editar coluna</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="36"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="76"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="64"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/columneditor.ui" line="29"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="78"/>
        <location filename="../columneditor.cpp" line="100"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="79"/>
        <location filename="../columneditor.cpp" line="101"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="81"/>
        <location filename="../columneditor.cpp" line="105"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="84"/>
        <location filename="../columneditor.cpp" line="108"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="85"/>
        <location filename="../columneditor.cpp" line="109"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="86"/>
        <location filename="../columneditor.cpp" line="110"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="87"/>
        <location filename="../columneditor.cpp" line="111"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="91"/>
        <location filename="../columneditor.cpp" line="116"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="92"/>
        <location filename="../columneditor.cpp" line="115"/>
        <source>Track Index</source>
        <translation>Índice da faixa</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="93"/>
        <source>Condition</source>
        <translation>Condição</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="102"/>
        <source>Artist - Album</source>
        <translation>Artista - Álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="103"/>
        <source>Artist - Title</source>
        <translation>Artista - Título</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="80"/>
        <location filename="../columneditor.cpp" line="104"/>
        <source>Album Artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="82"/>
        <location filename="../columneditor.cpp" line="106"/>
        <source>Track Number</source>
        <translation>Número da faixa</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="83"/>
        <location filename="../columneditor.cpp" line="107"/>
        <source>Two-digit Track Number</source>
        <translation>Número da faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="88"/>
        <location filename="../columneditor.cpp" line="112"/>
        <source>Disc Number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="89"/>
        <location filename="../columneditor.cpp" line="113"/>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="90"/>
        <location filename="../columneditor.cpp" line="114"/>
        <source>File Path</source>
        <translation>Caminho do ficheiro</translation>
    </message>
    <message>
        <location filename="../columneditor.cpp" line="117"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Definições do Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="58"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="67"/>
        <source>Plugins</source>
        <translation>Suplementos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="76"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="85"/>
        <source>Connectivity</source>
        <translation>Conectividade</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="94"/>
        <location filename="../forms/configdialog.ui" line="758"/>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="123"/>
        <source>Metadata</source>
        <translation>Meta-dados</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <source>Convert %20 to blanks</source>
        <translation>Converter %20 para espaços vazios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="129"/>
        <source>Load metadata from files</source>
        <translation>Carregar meta-dados dos ficheiros</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="136"/>
        <source>Convert underscores to blanks</source>
        <translation>Converter &quot;underscores&quot; para espaços vazios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="150"/>
        <source>Group format:</source>
        <translation>Formato de grupo:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="160"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="170"/>
        <source>Directory Scanning Options</source>
        <translation>Opções de análise de diretórios</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="176"/>
        <source>Restrict files to:</source>
        <translation>Restringir ficheiros a:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="186"/>
        <location filename="../forms/configdialog.ui" line="437"/>
        <source>Exclude files:</source>
        <translation>Ficheiros excluidos:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="199"/>
        <source>Miscellaneous</source>
        <translation>Diversos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="205"/>
        <source>Auto-save playlist when modified</source>
        <translation>Guardar lista de reprodução ao modificar</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="212"/>
        <source>Clear previous playlist when opening new one</source>
        <translation>Limpar lista de reprodução ao abrir uma nova</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="260"/>
        <location filename="../configdialog.cpp" line="329"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="273"/>
        <location filename="../configdialog.cpp" line="332"/>
        <source>Information</source>
        <translation>Informações</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="315"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="320"/>
        <source>Filename</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="332"/>
        <source>Look and Feel</source>
        <translation>Aspeto e comportamento</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="374"/>
        <source>Playback</source>
        <translation>Reprodução</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="380"/>
        <source>Continue playback on startup</source>
        <translation>Retomar reprodução ao iniciar</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="387"/>
        <source>Determine file type by content</source>
        <translation>Determinar tipo de ficheiro por conteúdo</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="394"/>
        <source>Add files from command line to this playlist:</source>
        <translation>Adicionar ficheiros da linha de comandos para a lista de reprodução:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="411"/>
        <source>Cover Image Retrieve</source>
        <translation>Obtenção de capa de álbum</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="417"/>
        <source>Use separate image files</source>
        <translation>Utilizar ficheiros de imagens distintos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="427"/>
        <source>Include files:</source>
        <translation>Ficheiros incluídos:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="449"/>
        <source>Recursive search depth:</source>
        <translation>Nível de procura recursiva:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="481"/>
        <source>URL Dialog</source>
        <translation>Diálogo de URL</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="487"/>
        <source>Auto-paste URL from clipboard</source>
        <translation>Colar URL existente na área de transferência</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="526"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="538"/>
        <source>Enable proxy usage</source>
        <translation>Ativar utilização de proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="545"/>
        <source>Proxy host name:</source>
        <translation>Nome do servidor proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="558"/>
        <source>Proxy port:</source>
        <translation>Porta do proxy:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="571"/>
        <source>Use authentication with proxy</source>
        <translation>Utilizar autenticação de proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="578"/>
        <source>Proxy user name:</source>
        <translation>Nome de utilizador:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="591"/>
        <source>Proxy password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Replay Gain</source>
        <translation>Replay Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="634"/>
        <source>Replay Gain mode:</source>
        <translation>Modo Replay Gain:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="651"/>
        <source>Preamp:</source>
        <translation>Amplificador:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="683"/>
        <location filename="../forms/configdialog.ui" line="728"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="696"/>
        <source>Default gain:</source>
        <translation>Ganho padrão:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="748"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Utilizar picos para impedir distorção</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="778"/>
        <source>Buffer size:</source>
        <translation>Memória:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="797"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="813"/>
        <source>Use software volume control</source>
        <translation>Utilizar controlo de volume da aplicação</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="823"/>
        <source>Volume adjustment step:</source>
        <translation>Valor para ajuste de volume:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="764"/>
        <source>Output bit depth:</source>
        <translation>Profundidade de saída:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="771"/>
        <source>Use dithering</source>
        <translation>Utilizar &apos;dithering&apos;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="69"/>
        <source>Track</source>
        <translation>Faixa</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="70"/>
        <location filename="../configdialog.cpp" line="313"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="71"/>
        <source>Disabled</source>
        <translation>Inativo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="87"/>
        <source>File Types</source>
        <translation>Tipos de ficheiro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="191"/>
        <source>Transports</source>
        <translation>Transporte</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="202"/>
        <source>Decoders</source>
        <translation>Descodificadores</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="213"/>
        <source>Engines</source>
        <translation>Mecanismos</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="224"/>
        <source>Effects</source>
        <translation>Efeitos</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="235"/>
        <source>Visualization</source>
        <translation>Visualização</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="246"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="257"/>
        <source>Output</source>
        <translation>Saída</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="268"/>
        <source>File Dialogs</source>
        <translation>Diálogos de ficheiro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="279"/>
        <source>User Interfaces</source>
        <translation>Interface de utilizador</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="312"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="314"/>
        <source>Album Artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="315"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="316"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="317"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="318"/>
        <source>Disc Number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="319"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="320"/>
        <source>Condition</source>
        <translation>Condição</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="321"/>
        <source>Artist/Album</source>
        <translation>Artista/Álbum</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="322"/>
        <source>Artist/Year/Album</source>
        <translation>Artista/Ano/Álbum</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="342"/>
        <source>&lt;Autodetect&gt;</source>
        <translation>&lt;Deteção automática&gt;</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="343"/>
        <source>Brazilian Portuguese</source>
        <translation>Português do Brasil</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="344"/>
        <source>Chinese Simplified</source>
        <translation>Mandarim simplificado</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="345"/>
        <source>Chinese Traditional</source>
        <translation>Mandarim tradicional</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="346"/>
        <source>Czech</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="347"/>
        <source>Dutch</source>
        <translation>Holândes</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="348"/>
        <source>English</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="349"/>
        <source>French</source>
        <translation>Francês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="350"/>
        <source>Galician</source>
        <translation>Galiciano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="351"/>
        <source>German</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="352"/>
        <source>Hebrew</source>
        <translation>Hebraico</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="353"/>
        <source>Hungarian</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="355"/>
        <source>Japanese</source>
        <translation>Japonês</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="356"/>
        <source>Kazakh</source>
        <translation>Cazaque</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="357"/>
        <source>Lithuanian</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="358"/>
        <source>Polish</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="359"/>
        <source>Portuguese</source>
        <translation>Português</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="360"/>
        <source>Russian</source>
        <translation>Russo</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="361"/>
        <source>Slovak</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="362"/>
        <source>Spanish</source>
        <translation>Espanhol</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="363"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="364"/>
        <source>Ukrainian</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="365"/>
        <source>Serbian (Ijekavian)</source>
        <translation>Sérvio (Ijekavian)</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Serbian (Ekavian)</source>
        <translation>Sérvio (Ekavian)</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../forms/detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="44"/>
        <source>Open the directory containing this file</source>
        <translation>Abrir o diretório que contém este ficheiro</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/detailsdialog.ui" line="63"/>
        <source>Summary</source>
        <translation>Resumo</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="132"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="177"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="178"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="179"/>
        <source>Album artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="180"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="181"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="182"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="183"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="185"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="187"/>
        <source>Track</source>
        <translation>Faixa</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="189"/>
        <source>Disc number</source>
        <translation>Número do disco</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Ira para a faixa</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="73"/>
        <location filename="../jumptotrackdialog.cpp" line="91"/>
        <location filename="../jumptotrackdialog.cpp" line="138"/>
        <source>Queue</source>
        <translation>Fila</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="89"/>
        <source>Refresh</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="105"/>
        <source>Jump To</source>
        <translation>Ir para</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="58"/>
        <source>Q</source>
        <translation>Q</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="59"/>
        <source>J</source>
        <translation>J</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="60"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="89"/>
        <location filename="../jumptotrackdialog.cpp" line="136"/>
        <source>Unqueue</source>
        <translation>Retirar da fila</translation>
    </message>
</context>
<context>
    <name>PlayListDownloader</name>
    <message>
        <location filename="../playlistdownloader.cpp" line="108"/>
        <source>Unsupported playlist format</source>
        <translation>Formato de lista não suportado</translation>
    </message>
</context>
<context>
    <name>PlayListHeaderModel</name>
    <message>
        <location filename="../playlistheadermodel.cpp" line="36"/>
        <source>Artist - Title</source>
        <translation>Artista - Título</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="186"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../playlistheadermodel.cpp" line="187"/>
        <source>Add Column</source>
        <translation>Adicionar coluna</translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="152"/>
        <location filename="../playlistmanager.cpp" line="309"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
</context>
<context>
    <name>PlayListTrack</name>
    <message>
        <location filename="../playlisttrack.cpp" line="255"/>
        <source>Streams</source>
        <translation>Emissões</translation>
    </message>
    <message>
        <location filename="../playlisttrack.cpp" line="260"/>
        <source>Empty group</source>
        <translation>Grupo vazio</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../winfileassoc.cpp" line="278"/>
        <source>Enqueue in Qmmp</source>
        <translation>Colocar na fila do Qmmp</translation>
    </message>
</context>
<context>
    <name>QmmpUiSettings</name>
    <message>
        <location filename="../qmmpuisettings.cpp" line="56"/>
        <source>Playlist</source>
        <translation>Lista de reprodução</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="35"/>
        <source>Qt File Dialog</source>
        <translation>Diálogo de ficheiro Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../forms/tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Editor de etiquetas</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Título:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="113"/>
        <source>Album artist:</source>
        <translation>Artista do álbum:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="123"/>
        <source>Composer:</source>
        <translation>Compositor:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="143"/>
        <source>Genre:</source>
        <translation>Género:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="169"/>
        <source>Track:</source>
        <translation>Faixa:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="190"/>
        <location filename="../forms/tageditor.ui" line="228"/>
        <location filename="../forms/tageditor.ui" line="260"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="203"/>
        <source>Year:</source>
        <translation>Ano:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="250"/>
        <source>Disc number:</source>
        <translation>Número do disco:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="275"/>
        <source>Comment:</source>
        <translation>Comentário:</translation>
    </message>
    <message>
        <location filename="../forms/tageditor.ui" line="311"/>
        <source>Include selected tag in file</source>
        <translation>Incluir etiqueta escolhida no ficheiro</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../forms/templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Editor de modelos</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Restaurar</translation>
    </message>
    <message>
        <location filename="../forms/templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Inserir</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Album Artist</source>
        <translation>Artista do álbum</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Track Number</source>
        <translation>Número da faixa</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Two-digit Track Number</source>
        <translation>Número da faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Genre</source>
        <translation>Género</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Composer</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Duration</source>
        <translation>Duração</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>Disc Number</source>
        <translation>Número do disco</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File Name</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>File Path</source>
        <translation>Caminho do ficheiro</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="64"/>
        <source>Condition</source>
        <translation>Condição</translation>
    </message>
</context>
<context>
    <name>UiHelper</name>
    <message>
        <location filename="../uihelper.cpp" line="139"/>
        <location filename="../uihelper.cpp" line="151"/>
        <source>All Supported Bitstreams</source>
        <translation>Todas as emissões suportadas</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="145"/>
        <source>Select one or more files to open</source>
        <translation>Selecione um ou mais ficheiros a abrir</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="157"/>
        <source>Select one or more files to play</source>
        <translation>Selecione um ou mais ficheiros a reproduzir</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="165"/>
        <source>Choose a directory</source>
        <translation>Selecione um diretório</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="181"/>
        <location filename="../uihelper.cpp" line="205"/>
        <source>Playlist Files</source>
        <translation>Ficheiros de lista de reprodução</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="183"/>
        <source>Open Playlist</source>
        <translation>Abrir lista de reprodução</translation>
    </message>
    <message>
        <location filename="../uihelper.cpp" line="206"/>
        <source>Save Playlist</source>
        <translation>Guardar lista de reprodução</translation>
    </message>
</context>
<context>
    <name>WinFileAssocPage</name>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="17"/>
        <source>Media files handled by Qmmp:</source>
        <translation>Ficheiros geridos pelo Qmmp:</translation>
    </message>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="49"/>
        <source>Select All</source>
        <translation>Marcar todos</translation>
    </message>
    <message>
        <location filename="../forms/winfileassocpage.ui" line="56"/>
        <source>Select None</source>
        <translation>Desmarcar todos</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="136"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="137"/>
        <source>Not all files could be associated. Please check your security permissions and retry.</source>
        <translation>Nem todos os tipos de ficheiro foram associados. Verifique as suas permissões e tente novamente.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="144"/>
        <source>Check all file types in the list</source>
        <translation>Marcar todos os tipos de ficheiro da lista</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="145"/>
        <source>Uncheck all file types in the list</source>
        <translation>Desmarcar todos os tipos de ficheiro da lista</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="146"/>
        <source>Check the media file extensions you would like Qmmp to handle. When you click Apply, the checked files will be associated with Qmmp. If you uncheck a media type, the file association will be restored.</source>
        <translation>Assinale as extensões de ficheiros que pretende gerir com o Qmmp. Se clicar em Aplicar, os tipos de ficheiro marcados serão associados. Se desmarcar um tipo, a associação original será restaurada.</translation>
    </message>
    <message>
        <location filename="../winfileassocpage.cpp" line="150"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Restoration doesn&apos;t work on Windows Vista/7.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; o restauro não funciona nos sistemas Windows Vista/7.</translation>
    </message>
</context>
</TS>
